@@ -9,9 +9,9 @@ import google.protobuf.message as msg
 import ibis.expr.datatypes as dt
 import ibis.expr.types as ir
 
-from ..proto.substrait import algebra_pb2 as stalg
-from ..proto.substrait import plan_pb2 as stp
-from ..proto.substrait.extensions import extensions_pb2 as ste
+from ..proto.substrait.ibis import algebra_pb2 as stalg
+from ..proto.substrait.ibis import plan_pb2 as stp
+from ..proto.substrait.ibis.extensions import extensions_pb2 as ste
 from .mapping import IBIS_SUBSTRAIT_OP_MAPPING
 
 
@@ -143,13 +143,13 @@ def _get_fields(dtype: dt.DataType) -> Iterator[tuple[str | None, dt.DataType]]:
     Examples
     --------
     >>> import ibis.expr.datatypes as dt
-    >>> array_type = dt.parse_type("array<int64>")
+    >>> array_type = dt.parse("array<int64>")
     >>> list(_get_fields(array_type))  # doctest: +SKIP
     [(None, int64)]
-    >>> map_type = dt.parse_type("map<string, string>")
+    >>> map_type = dt.parse("map<string, string>")
     >>> list(_get_fields(map_type))
     [(None, String(nullable=True)), (None, String(nullable=True))]
-    >>> struct_type = dt.parse_type("struct<a: int64, b: map<int64, float64>>")
+    >>> struct_type = dt.parse("struct<a: int64, b: map<int64, float64>>")
     >>> list(_get_fields(struct_type))  # doctest: +SKIP
     [('b', Map(key_type=int64, value_type=float64, nullable=True)), ('a', int64)]
     """
